=======================
How-to-contribute Video
=======================

There are generally three steps involved in submiting your code: *download*, *edit* 
and *upload*.

.. raw:: html

    <iframe width="560" height="315" src="https://www.dropbox.com/s/j1xdl0q7zj039cl/%28with%20clicks%29%20how-to-contribute-an-example-in-espresso.mp4?dl=0&raw=1" frameborder="0" allowfullscreen></iframe>

If your browser fails to load the video, head to 
`this link <https://dl.dropbox.com/s/j1xdl0q7zj039cl/%28with%20clicks%29%20how-to-contribute-an-example-in-espresso.mp4?dl=0>`_ 
to watch it.
